# st-card

Streamlit Component, for a UI card

authors - [@gamcoh](https://github.com/gamcoh) @Pernod Ricard

## Installation

Install `streamlit-card` with pip
```bash
pip install streamlit-card 
```

usage, import the `card` function from `streamlit_card`
```py
from streamlit_card import card

card(title="Hello World!", text="Some description", image="http://placekitten.com/200/300")
```
   
